@@ -1,13 +1,16 @@
-__all__ = ["Browser", "BrowserSettings", "BrowserType", "CookieBannerSettings", "LoginCredentials",
-           "LoginForm1Step", "LoginForm2Steps", "PageLoadStrategy", "SearchSettings", "TimeoutSettings", "TimeoutStrategy"]
+__all__ = ["Browser", "BrowserSettings", "BrowserType", "common_devices", "CookieBannerSettings", "DeviceViewportSize",
+           "LoginCredentials", "LoginForm1Step", "LoginForm2Steps", "PageLoadStrategy", "SearchSettings", "TimeoutSettings", "TimeoutStrategy"]
 
 from .browser.__main__ import Browser
 from .model.browser.base.page_load_strategy import PageLoadStrategy
 from .model.browser.base.settings import BrowserSettings
+from .model.browser.base.timeout.settings import TimeoutSettings
+from .model.browser.base.timeout.strategy import TimeoutStrategy
 from .model.browser.base.type import BrowserType
 from .model.combo_settings.cookie_banner import CookieBannerSettings
 from .model.combo_settings.login_credentials import LoginCredentials
 from .model.combo_settings.login_form import LoginForm1Step, LoginForm2Steps
 from .model.combo_settings.search import SearchSettings
-from .model.timeout_strategy import TimeoutSettings, TimeoutStrategy
+from .model.viewport import common_devices
+from .model.viewport.device import DeviceViewportSize
 from .version import __version__  # noqa
