@@ -8,6 +8,7 @@ from ..model.browser.base.settings import BrowserSettings
 from ..model.browser.base.type import BrowserType
 from ..model.browser.extension.internet_explorer import InternetExplorerBrowserExtension
 from ..model.browser.extension.safari import SafariBrowserExtension
+from ..model.viewport.device import DeviceViewportSize
 from .check_if.__main__ import CheckIfDriverMethods
 from .click.__main__ import ClickDriverMethods
 from .combo.__main__ import ComboDriverMethods
@@ -16,11 +17,10 @@ from .iframe.__main__ import IframeDriverMethods
 from .input.__main__ import InputDriverMethods
 from .mouse.__main__ import MouseDriverMethods
 from .open.__main__ import OpenDriverMethods
-from .screen.__main__ import ScreenSizeDriverMethods
 from .screenshot.__main__ import ScreenshotDriverMethods
 from .scroll.__main__ import ScrollDriverMethods
-from .select.__main__ import SelectDriverMethods
 from .tool.__main__ import ToolDriverMethods
+from .viewport.__main__ import ViewportDriverMethods
 from .wait.__main__ import WaitDriverMethods
 from .window.__main__ import WindowDriverMethods
 
@@ -29,18 +29,42 @@ class Browser:
     """Main class of Browserist that sets the Selenium web driver and contains all helper functions."""
 
     __slots__ = ["_browser_driver", "driver", "ie", "safari",
-                 "check_if", "click", "combo", "get", "iframe", "input", "mouse", "open", "screen", "screenshot", "scroll", "select", "tool", "wait", "window"]
+                 "check_if", "click", "combo", "get", "iframe", "input", "mouse", "open", "screenshot", "scroll", "select", "tool", "viewport", "wait", "window"]
 
     def __init__(self, settings: BrowserSettings | None = None) -> None:
-        """Initiates the browser driver whether the settings calls for Chrome, Firefox, etc."""
+        """Initiates the browser driver whether the settings call for Chrome, Firefox, etc."""
 
         if settings is None:
             settings = BrowserSettings()  # Use default settings if no custom settings are given.
 
         self._browser_driver: BrowserDriver = factory.get.browser_driver(settings)
-        self.driver: object = self._browser_driver.webdriver
+        self.driver: object = self._browser_driver.get_webdriver()
 
-        match self._browser_driver.settings.type:
+        self.check_if: CheckIfDriverMethods = CheckIfDriverMethods(self._browser_driver)
+        self.click: ClickDriverMethods = ClickDriverMethods(self._browser_driver)
+        self.combo: ComboDriverMethods = ComboDriverMethods(self._browser_driver)
+        self.get: GetDriverMethods = GetDriverMethods(self._browser_driver)
+        self.iframe: IframeDriverMethods = IframeDriverMethods(self._browser_driver)
+        self.input: InputDriverMethods = InputDriverMethods(self._browser_driver)
+        self.mouse: MouseDriverMethods = MouseDriverMethods(self._browser_driver)
+        self.open: OpenDriverMethods = OpenDriverMethods(self._browser_driver)
+        self.screenshot: ScreenshotDriverMethods = ScreenshotDriverMethods(self._browser_driver)
+        self.scroll: ScrollDriverMethods = ScrollDriverMethods(self._browser_driver)
+        self.tool: ToolDriverMethods = ToolDriverMethods(self._browser_driver)
+        self.viewport: ViewportDriverMethods = ViewportDriverMethods(self._browser_driver)
+        self.wait: WaitDriverMethods = WaitDriverMethods(self._browser_driver)
+        self.window: WindowDriverMethods = WindowDriverMethods(self._browser_driver)
+
+        match settings.viewport:
+            case DeviceViewportSize():
+                self.viewport.set.size_by_device(settings.viewport)
+            case tuple():
+                width, height = settings.viewport
+                self.viewport.set.size(width, height)
+            case _:
+                pass
+
+        match settings.type:
             case BrowserType.INTERNET_EXPLORER:
                 self.ie: InternetExplorerBrowserExtension = InternetExplorerBrowserExtension(self._browser_driver)
             case BrowserType.SAFARI:
@@ -48,22 +72,6 @@ class Browser:
             case _:
                 pass
 
-        self.check_if: CheckIfDriverMethods = CheckIfDriverMethods(self._browser_driver, settings)
-        self.click: ClickDriverMethods = ClickDriverMethods(self._browser_driver, settings)
-        self.combo: ComboDriverMethods = ComboDriverMethods(self._browser_driver, settings)
-        self.get: GetDriverMethods = GetDriverMethods(self._browser_driver, settings)
-        self.iframe: IframeDriverMethods = IframeDriverMethods(self._browser_driver, settings)
-        self.input: InputDriverMethods = InputDriverMethods(self._browser_driver, settings)
-        self.mouse: MouseDriverMethods = MouseDriverMethods(self._browser_driver, settings)
-        self.open: OpenDriverMethods = OpenDriverMethods(self._browser_driver, settings)
-        self.screen: ScreenSizeDriverMethods = ScreenSizeDriverMethods(self._browser_driver, settings)
-        self.screenshot: ScreenshotDriverMethods = ScreenshotDriverMethods(self._browser_driver, settings)
-        self.scroll: ScrollDriverMethods = ScrollDriverMethods(self._browser_driver, settings)
-        self.select: SelectDriverMethods = SelectDriverMethods(self._browser_driver, settings)
-        self.tool: ToolDriverMethods = ToolDriverMethods(self._browser_driver, settings)
-        self.wait: WaitDriverMethods = WaitDriverMethods(self._browser_driver, settings)
-        self.window: WindowDriverMethods = WindowDriverMethods(self._browser_driver, settings)
-
     def __enter__(self) -> Browser:
         return self
 
