@@ -1,11 +1,12 @@
 from ..browser.get.url.current import get_current_url
+from ..model.browser.base.driver import BrowserDriver
 
 
 class NoElementFoundException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, xpath: str) -> None:
-        current_url = get_current_url(driver)
+    def __init__(self, browser_driver: BrowserDriver, xpath: str) -> None:
+        current_url = get_current_url(browser_driver)
         self.message = f"On page {current_url}, no such element found while waiting: {xpath}"
         super().__init__(self.message)
 
@@ -16,8 +17,8 @@ class NoElementFoundException(Exception):
 class NoElementFoundWithTextConditionException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, xpath: str, text_condition: str) -> None:
-        current_url = get_current_url(driver)
+    def __init__(self, browser_driver: BrowserDriver, xpath: str, text_condition: str) -> None:
+        current_url = get_current_url(browser_driver)
         self.message = f"On page {current_url}, an element that contains \"{text_condition}\" could not be found: {xpath}"
         super().__init__(self.message)
 
@@ -28,8 +29,8 @@ class NoElementFoundWithTextConditionException(Exception):
 class NoElementDimensionsFoundException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, xpath: str) -> None:
-        current_url = get_current_url(driver)
+    def __init__(self, browser_driver: BrowserDriver, xpath: str) -> None:
+        current_url = get_current_url(browser_driver)
         self.message = f"On page {current_url}, no such element found while trying to get element dimensions: {xpath}"
         super().__init__(self.message)
 
