@@ -1,12 +1,13 @@
 from ..browser.get.page_title import get_page_title
 from ..browser.get.url.current import get_current_url
+from ..model.browser.base.driver import BrowserDriver
 
 
 class WaitForElementTimeoutException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, xpath: str) -> None:
-        current_url = get_current_url(driver)
+    def __init__(self, browser_driver: BrowserDriver, xpath: str) -> None:
+        current_url = get_current_url(browser_driver)
         self.message = f"On page {current_url}, waiting for element timed out: {xpath}"
         super().__init__(self.message)
 
@@ -17,9 +18,9 @@ class WaitForElementTimeoutException(Exception):
 class WaitForPageTitleToChangeTimeoutException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, page_title_or_fragment: str) -> None:
-        current_url = get_current_url(driver)
-        page_title = get_page_title(driver)
+    def __init__(self, browser_driver: BrowserDriver, page_title_or_fragment: str) -> None:
+        current_url = get_current_url(browser_driver)
+        page_title = get_page_title(browser_driver)
         self.message = f"On page {current_url} with title \"{page_title}\", check of page title fragment timed out, or the title fragment doesn't match: {page_title_or_fragment}"
         super().__init__(self.message)
 
@@ -30,8 +31,8 @@ class WaitForPageTitleToChangeTimeoutException(Exception):
 class WaitForUrlTimeoutException(Exception):
     __slots__ = ["message"]
 
-    def __init__(self, driver: object, url: str) -> None:
-        current_url = get_current_url(driver)
+    def __init__(self, browser_driver: BrowserDriver, url: str) -> None:
+        current_url = get_current_url(browser_driver)
         self.message = f"On page {current_url}, waiting for URL timed out, or the URL fragment doesn't exist: {url}"
         super().__init__(self.message)
 
