@@ -1,5 +1,7 @@
 from PIL import Image  # type: ignore
 
+from ..model.type.path import FilePath
+
 
 def is_element_loaded(driver: object, element: object) -> bool:
     """Check if image element is loaded and ready in the DOM."""
@@ -18,6 +20,9 @@ def merge_vertically(image_base: Image, image_add: Image) -> Image:  # type: ign
     merged_image = Image.new("RGB", (merged_image_width, merged_image_height))
     merged_image.paste(image_base, (0, 0))
     merged_image.paste(image_add, (0, image_base.height))
+    # Rememeber to close images so we avoid PermissionError on especially Windows when trying to remove temporary files:
+    image_base.close()
+    image_add.close()
     return merged_image
 
 
@@ -27,7 +32,7 @@ def open(file_path: str) -> Image:  # type: ignore
     return Image.open(file_path)
 
 
-def save(image: Image, file_path: str) -> Image:  # type: ignore
+def save(image: Image, file_path: FilePath) -> Image:  # type: ignore
     """Save image to file path."""
 
     return image.save(file_path)
