@@ -21,7 +21,7 @@ class BrowserDriver(ABC):
         """Initiates basic properties of the Selenium web driver."""
 
         self.settings = settings
-        helper.directory.create_if_not_exists(self.settings.screenshot_dir)
+        helper.directory.create_if_not_exists(self.settings._screenshot_dir)
 
         match(self.settings.type):
             case BrowserType.CHROME | BrowserType.OPERA:
@@ -33,7 +33,7 @@ class BrowserDriver(ABC):
             case BrowserType.INTERNET_EXPLORER:
                 self.ie_options: IEOptions = IEOptions()  # type: ignore
             case BrowserType.SAFARI:
-                self.safari_options: SafariOptions = SafariOptions()  # type: ignore
+                self.safari_options: SafariOptions = SafariOptions()
 
         self.ensure_browser_type()
         self.set_options_and_profile()
@@ -52,7 +52,7 @@ class BrowserDriver(ABC):
         raise NotImplementedError
 
     def set_options_and_profile(self) -> None:
-        """Internal task initialiser that runs the configuration methods to disable images, enable headless, etc."""
+        """Internal task initializer that runs the configuration methods to disable images, enable headless, etc."""
 
         self.disable_images()
         self.enable_headless()
@@ -75,3 +75,8 @@ class BrowserDriver(ABC):
         """Method to set the page load strategy to define whether the web driver should wait until all assets are downloaded (slower) or not (faster)."""
 
         raise NotImplementedError
+
+    def get_webdriver(self) -> object:
+        """Returns the Selenium web driver."""
+
+        return self.webdriver
