@@ -10,12 +10,12 @@ class ChromeBrowserDriver(BrowserDriver):
         self.settings.type = BrowserType.CHROME
 
     def set_webdriver(self) -> object:
-        if self.settings.path_to_executable is None:
+        if self.settings._path_to_executable is None:
             return webdriver.Chrome(
                 options=self.chrome_options)
         else:
             return webdriver.Chrome(
-                executable_path=self.settings.path_to_executable,
+                executable_path=self.settings._path_to_executable,
                 options=self.chrome_options)
 
     def disable_images(self) -> None:
