@@ -10,12 +10,12 @@ class EdgeBrowserDriver(BrowserDriver):
         self.settings.type = BrowserType.EDGE
 
     def set_webdriver(self) -> object:
-        if self.settings.path_to_executable is None:
+        if self.settings._path_to_executable is None:
             return webdriver.Edge(
                 options=self.edge_options)
         else:
             return webdriver.Edge(
-                executable_path=self.settings.path_to_executable,
+                executable_path=self.settings._path_to_executable,
                 options=self.edge_options)
 
     def disable_images(self) -> None:
