@@ -11,12 +11,12 @@ class SafariBrowserDriver(BrowserDriver):
         self.settings.type = BrowserType.SAFARI
 
     def set_webdriver(self) -> object:
-        if self.settings.path_to_executable is None:
+        if self.settings._path_to_executable is None:
             return webdriver.Safari(
                 options=self.safari_options)
         else:
             return webdriver.Safari(
-                executable_path=self.settings.path_to_executable,
+                executable_path=self.settings._path_to_executable,
                 options=self.safari_options)
 
     def disable_images(self) -> None:
