@@ -1,6 +1,7 @@
-from typing import Any, Callable
+from collections.abc import Callable
+from typing import Any
 
-DriverGetTextCallable = Callable[[object, str], str]
+DriverGetTextCallable = Callable[..., str]
 
 DriverGetBoolCallable = Callable[..., bool]
 
@@ -11,3 +12,5 @@ BrowserMethodWith3ArgumentsCallable = Callable[[object, str, Any], None]
 BrowserMethodWith4ArgumentsCallable = Callable[[object, str, Any, Any], None]
 
 BrowserMethodWith5ArgumentsCallable = Callable[[object, str, Any, Any, Any], None]
+
+TimeoutShouldContinueCallable = Callable[[], bool]
